@@ -1,5 +1,9 @@
 /* Ekiga -- A VoIP and Video-Conferencing application
  * Copyright (C) 2000-2009 Damien Sandras <dsandras@seconix.com>
+ * Copyright (C) 2012, Xunta de Galicia <ocfloss@xunta.es>
+ *
+ * Authors: Matthias Schneider
+ *          Victor Jaquez, Igalia S.L., AGASOL. <vjaquez@igalia.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -96,7 +100,7 @@ GMVideoOutputManager::Main ()
 
     if (initialised_thread) {
       var_mutex.Wait ();
-        do_sync = local_frame_received | remote_frame_received;
+        do_sync = local_frame_received | remote_frame_received | ext_frame_received;
         if (do_sync)
           sync_required = redraw();
       var_mutex.Signal ();
@@ -151,6 +155,14 @@ void GMVideoOutputManager::set_frame_data (const char* data,
     current_frame.remote_height= height;
     memcpy (rframeStore.GetPointer(), data, (width * height * 3) >> 1);
     remote_frame_received = true;
+  }
+  else if (type == 2) { // REMOTE 2 (extended video)
+    /* memcpy the frame */
+    eframeStore.SetSize (width * height * 3);
+    current_frame.ext_width = width;
+    current_frame.ext_height= height;
+    memcpy (eframeStore.GetPointer(), data, (width * height * 3) >> 1);
+    ext_frame_received = true;
   } else {
     var_mutex.Signal();
     run_thread.Signal();
@@ -171,6 +183,7 @@ void GMVideoOutputManager::set_frame_data (const char* data,
     }
 
     current_frame.both_streams_active = false;
+    current_frame.ext_stream_active = false;
   } else {
 
     if (local_frame_received && !remote_frame_received)
@@ -180,6 +193,7 @@ void GMVideoOutputManager::set_frame_data (const char* data,
         local_display_info.mode = Ekiga::VO_MODE_REMOTE;
 
     current_frame.both_streams_active = local_frame_received & remote_frame_received;
+    current_frame.ext_stream_active = ext_frame_received;
   }
   current_frame.mode = local_display_info.mode;
   current_frame.zoom = local_display_info.zoom;
@@ -191,13 +205,20 @@ void GMVideoOutputManager::set_frame_data (const char* data,
     }
     update_required.local = true;
   }
-  else {
+  else if (type == 1) {
 
     if (update_required.remote) {
       PTRACE(3, "GMVideoOutputManager\tSkipped earlier remote frame");
     }
     update_required.remote = true;
   }
+  else if (type == 2) {
+
+    if (update_required.extended) {
+      PTRACE(3, "GMVideoOutputManager\tSkipped earlier extended frame");
+    }
+    update_required.extended = true;
+  }
 
   var_mutex.Signal();
 
@@ -207,10 +228,13 @@ void GMVideoOutputManager::set_frame_data (const char* data,
   }
 
   if ((local_display_info.mode == Ekiga::VO_MODE_LOCAL) && !local)
-      return;
+    return;
 
-  if ((local_display_info.mode == Ekiga::VO_MODE_REMOTE) && local)
-      return;
+  if (local_display_info.mode == Ekiga::VO_MODE_REMOTE && type != 1)
+    return;
+
+  if (local_display_info.mode == Ekiga::VO_MODE_REMOTE_EXT && type != 2)
+    return;
 
   run_thread.Signal();
 }
@@ -222,27 +246,35 @@ void GMVideoOutputManager::init()
   last_frame.mode = Ekiga::VO_MODE_UNSET;
   last_frame.accel = Ekiga::VO_ACCEL_NO_VIDEO;
   last_frame.both_streams_active = false;
+  last_frame.ext_stream_active = false;
 
   last_frame.local_width = 0;
   last_frame.local_height = 0;
   last_frame.remote_width = 0;
-  last_frame.remote_height = 0;  
+  last_frame.remote_height = 0;
+  last_frame.ext_width = 0;
+  last_frame.ext_height = 0;
   last_frame.zoom = 0;
   last_frame.embedded_x = 0;
-  last_frame.embedded_y = 0;  
+  last_frame.embedded_y = 0;
 
+  current_frame.ext_stream_active = false;
   current_frame.both_streams_active = false;
   current_frame.local_width = 0;
   current_frame.local_height = 0;
   current_frame.remote_width = 0;
   current_frame.remote_height = 0;
+  current_frame.ext_width = 0;
+  current_frame.ext_height = 0;
 
   /* Initialisation */
   video_disabled = false;
   local_frame_received = false;
   remote_frame_received = false;
+  ext_frame_received = false;
   update_required.local = false;
   update_required.remote = false;
+  update_required.extended = false;
 
 }
 
@@ -251,58 +283,78 @@ void GMVideoOutputManager::uninit ()
   /* This is common to all output classes */
   lframeStore.SetSize (0);
   rframeStore.SetSize (0);
+  eframeStore.SetSize (0);
 }
 
 void GMVideoOutputManager::update_gui_device ()
 {
   last_frame.both_streams_active = current_frame.both_streams_active;
-  Ekiga::Runtime::run_in_main (boost::bind (&GMVideoOutputManager::device_closed_in_main, this));
-  Ekiga::Runtime::run_in_main (boost::bind (&GMVideoOutputManager::device_opened_in_main, this, current_frame.accel, current_frame.mode, current_frame.zoom, current_frame.both_streams_active));
+  last_frame.ext_stream_active = current_frame.ext_stream_active;
 
+  Ekiga::Runtime::run_in_main (boost::bind (&GMVideoOutputManager::device_closed_in_main, this));
+
+  Ekiga::Runtime::run_in_main
+    (boost::bind (&GMVideoOutputManager::device_opened_in_main, this,
+                  current_frame.accel, current_frame.mode, current_frame.zoom,
+                  current_frame.both_streams_active,
+                  current_frame.ext_stream_active));
 }
 
-
-bool 
+bool
 GMVideoOutputManager::frame_display_change_needed ()
 {
   Ekiga::DisplayInfo local_display_info;
 
   get_display_info(local_display_info);
 
-  if ((!local_display_info.widget_info_set) || (!local_display_info.config_info_set) ||
-      (local_display_info.mode == Ekiga::VO_MODE_UNSET) || (local_display_info.zoom == 0)) {
+  if ((!local_display_info.widget_info_set) ||
+      (!local_display_info.config_info_set) ||
+      (local_display_info.mode == Ekiga::VO_MODE_UNSET) ||
+      (local_display_info.zoom == 0)) {
     PTRACE(4, "GMVideoOutputManager\tWidget not yet realized or gconf info not yet set, not opening display");
     return false;
   }
 
-  if ( last_frame.mode != current_frame.mode || last_frame.zoom != current_frame.zoom )
+  if ( last_frame.mode != current_frame.mode ||
+       last_frame.zoom != current_frame.zoom )
     return true;
 
+  bool local_changed = (last_frame.local_width  != current_frame.local_width ||
+                        last_frame.local_height != current_frame.local_height);
+  bool remote_changed = (last_frame.remote_width  != current_frame.remote_width ||
+                         last_frame.remote_height != current_frame.remote_height);
+  bool window_changed = (local_display_info.x != last_frame.embedded_x ||
+                        local_display_info.y != last_frame.embedded_y);
+  bool ext_changed = (last_frame.ext_width  != current_frame.ext_width ||
+                      last_frame.ext_height != current_frame.ext_height);
+
   switch (current_frame.mode) {
   case Ekiga::VO_MODE_LOCAL:
-    return (   last_frame.local_width  != current_frame.local_width   || last_frame.local_height != current_frame.local_height 
-            || local_display_info.x    != last_frame.embedded_x       || local_display_info.y    != last_frame.embedded_y );
+    return ( local_changed || window_changed );
     break;
 
   case Ekiga::VO_MODE_REMOTE:
-    return (   last_frame.remote_width != current_frame.remote_width || last_frame.remote_height != current_frame.remote_height
-            || local_display_info.x    != last_frame.embedded_x      || local_display_info.y     != last_frame.embedded_y);
+    return ( remote_changed || window_changed );
     break;
 
   case Ekiga::VO_MODE_PIP:
-    return (   last_frame.remote_width != current_frame.remote_width || last_frame.remote_height != current_frame.remote_height
-            || last_frame.local_width  != current_frame.local_width  || last_frame.local_height  != current_frame.local_height
-            || local_display_info.x    != last_frame.embedded_x      || local_display_info.y     != last_frame.embedded_y);
+    return ( remote_changed || local_changed || window_changed );
     break;
+
   case Ekiga::VO_MODE_PIP_WINDOW:
   case Ekiga::VO_MODE_FULLSCREEN:
-    return (   last_frame.remote_width != current_frame.remote_width || last_frame.remote_height != current_frame.remote_height
-            || last_frame.local_width  != current_frame.local_width  || last_frame.local_height  != current_frame.local_height);
+    return ( remote_changed || local_changed );
     break;
+
+  case Ekiga::VO_MODE_REMOTE_EXT:
+    return ( ext_changed || window_changed );
+    break;
+
   case Ekiga::VO_MODE_UNSET:
   default:
     break;
   }
+
   return false;
 }
 
@@ -311,32 +363,43 @@ GMVideoOutputManager::redraw ()
 {
   UpdateRequired sync_required;
   sync_required = update_required;
-  
-    if (frame_display_change_needed ()) 
-      setup_frame_display (); 
+
+    if (frame_display_change_needed ())
+      setup_frame_display ();
      else
-      if (last_frame.both_streams_active != current_frame.both_streams_active)
+      if (last_frame.both_streams_active != current_frame.both_streams_active ||
+          last_frame.ext_stream_active != current_frame.ext_stream_active)
         update_gui_device();
 
-    switch (current_frame.mode) 
-      {
-      case Ekiga::VO_MODE_LOCAL:
-          if (lframeStore.GetSize() > 0)
-            display_frame ((char*)lframeStore.GetPointer (), current_frame.local_width, current_frame.local_height);
+    switch (current_frame.mode) {
+    case Ekiga::VO_MODE_LOCAL:
+      if (lframeStore.GetSize() > 0)
+        display_frame ((char *) lframeStore.GetPointer (),
+                       current_frame.local_width, current_frame.local_height);
         break;
 
-      case Ekiga::VO_MODE_REMOTE:
-          if (rframeStore.GetSize() > 0)
-            display_frame ((char*)rframeStore.GetPointer (), current_frame.remote_width, current_frame.remote_height);
-        break;
+    case Ekiga::VO_MODE_REMOTE:
+      if (rframeStore.GetSize() > 0)
+        display_frame ((char *) rframeStore.GetPointer (),
+                       current_frame.remote_width, current_frame.remote_height);
+      break;
 
-     case Ekiga::VO_MODE_FULLSCREEN:
-     case Ekiga::VO_MODE_PIP:
-     case Ekiga::VO_MODE_PIP_WINDOW:
-          if ((lframeStore.GetSize() > 0) &&  (rframeStore.GetSize() > 0))
-            display_pip_frames ((char*)lframeStore.GetPointer (), current_frame.local_width, current_frame.local_height,
-                              (char*)rframeStore.GetPointer (), current_frame.remote_width, current_frame.remote_height);
+    case Ekiga::VO_MODE_FULLSCREEN:
+    case Ekiga::VO_MODE_PIP:
+    case Ekiga::VO_MODE_PIP_WINDOW:
+      if ((lframeStore.GetSize() > 0) &&  (rframeStore.GetSize() > 0))
+        display_pip_frames ((char *) lframeStore.GetPointer (),
+                            current_frame.local_width, current_frame.local_height,
+                            (char *) rframeStore.GetPointer (),
+                            current_frame.remote_width, current_frame.remote_height);
        break;
+
+    case Ekiga::VO_MODE_REMOTE_EXT:
+      if (eframeStore.GetSize() > 0)
+        display_frame ((char *) eframeStore.GetPointer (),
+                       current_frame.ext_width, current_frame.ext_height);
+      break;
+
     case Ekiga::VO_MODE_UNSET:
     default:
        break;
@@ -344,6 +407,7 @@ GMVideoOutputManager::redraw ()
 
   update_required.local = false;
   update_required.remote = false;
+  update_required.extended = false;
 
   return sync_required;
 }
@@ -353,9 +417,9 @@ void
 GMVideoOutputManager::device_opened_in_main (Ekiga::VideoOutputAccel accel,
 					     Ekiga::VideoOutputMode mode,
 					     unsigned zoom,
-					     bool both)
+					     bool both, bool ext)
 {
-  device_opened (accel, mode, zoom, both);
+  device_opened (accel, mode, zoom, both, ext);
 }
 
 void
