@@ -35,6 +35,8 @@
  *
  */
 
+#include "config.h"
+
 #include <string.h>
 #include <stdlib.h>
 #include <algorithm>
@@ -58,18 +60,20 @@
 #include "audiooutput-core.h"
 
 #include "sip-endpoint.h"
+#ifdef HAVE_H323
+#include "h323-endpoint.h"
+#endif
 
 Opal::Account::Account (Ekiga::ServiceCore & _core,
                         const std::string & account)
   : core (_core)
 {
-  endpoint = core.get<Sip::EndPoint> ("opal-sip-endpoint");
   notification_core = core.get<Ekiga::NotificationCore> ("notification-core");
-  dead = false;
   state = Unregistered;
   status = _("Unregistered");
   message_waiting_number = 0;
   failed_registration_already_notified = false;
+  dead = false;
 
   int i = 0;
   char *pch = strtok ((char *) account.c_str (), "|");
@@ -135,10 +139,20 @@ Opal::Account::Account (Ekiga::ServiceCore & _core,
   else
     type = Account::H323;
 
-  if (name.find ("%limit") != std::string::npos)
-    compat_mode = SIPRegister::e_CannotRegisterMultipleContacts;  // start registration in this compat mode
-  else
-    compat_mode = SIPRegister::e_FullyCompliant;
+#ifdef HAVE_H323
+  if (type == Account::H323)
+    h323_endpoint = core.get<H323::EndPoint> ("opal-h323-endpoint");
+  else {
+#endif
+    sip_endpoint = core.get<Sip::EndPoint> ("opal-sip-endpoint");
+
+    if (name.find ("%limit") != std::string::npos)
+      compat_mode = SIPRegister::e_CannotRegisterMultipleContacts;  // start registration in this compat mode
+    else
+      compat_mode = SIPRegister::e_FullyCompliant;
+#ifdef HAVE_H323
+  }
+#endif
 
   setup_presentity ();
 }
@@ -155,10 +169,8 @@ Opal::Account::Account (Ekiga::ServiceCore & _core,
                         unsigned _timeout)
   : core (_core)
 {
-  endpoint = core.get<Sip::EndPoint> ("opal-sip-endpoint");
   notification_core = core.get<Ekiga::NotificationCore> ("notification-core");
 
-  dead = false;
   state = Unregistered;
   status = "";
   message_waiting_number = 0;
@@ -176,6 +188,14 @@ Opal::Account::Account (Ekiga::ServiceCore & _core,
   timeout = _timeout;
   type = t;
   failed_registration_already_notified = false;
+  dead = false;
+
+#ifdef HAVE_H323
+  if (type == Account::H323)
+    h323_endpoint = core.get<H323::EndPoint> ("opal-h323-endpoint");
+  else
+#endif
+    sip_endpoint = core.get<Sip::EndPoint> ("opal-sip-endpoint");
 
   setup_presentity ();
 
@@ -184,20 +204,13 @@ Opal::Account::Account (Ekiga::ServiceCore & _core,
 }
 
 
-Opal::Account::~Account ()
-{
-  if (!dead && state == Registered)
-    endpoint->unsubscribe (*this, presentity);
-}
-
-
 const std::string Opal::Account::as_string () const
 {
+  std::stringstream str;
+
   if (dead)
     return "";
 
-  std::stringstream str;
-
   str << enabled << "|1|"
       << aid << "|"
       << name << "|"
@@ -306,7 +319,12 @@ void Opal::Account::enable ()
 
   state = Processing;
   status = _("Processing...");
-  endpoint->subscribe (*this, presentity);
+#ifdef HAVE_H323
+  if (type == Account::H323)
+    h323_endpoint->subscribe (*this, presentity);
+  else
+#endif
+    sip_endpoint->subscribe (*this, presentity);
 
   updated ();
   trigger_saving ();
@@ -317,27 +335,27 @@ void Opal::Account::disable ()
 {
   enabled = false;
 
+  if (presentity) {
+
+    for (std::set<std::string>::iterator iter = watched_uris.begin ();
+         iter != watched_uris.end (); ++iter) {
+      presentity->UnsubscribeFromPresence (PString (*iter));
+      Ekiga::Runtime::run_in_main (boost::bind (&Opal::Account::presence_status_in_main, this, *iter, "unknown", ""));
+    }
+  }
+#ifdef HAVE_H323
+  if (type == Account::H323)
+    h323_endpoint->unsubscribe (*this, presentity);
+  else
+#endif
+    sip_endpoint->unsubscribe (*this, presentity);
+
   // Translators: this is a state, not an action, i.e. it should be read as
   // "(you are) unregistered", and not as "(you have been) unregistered"
   status = _("Unregistered");
 
   updated ();
   trigger_saving ();
-
-  // the above change is needed because if we are already not
-  // registered (because a registration failed, for example), then the
-  // next action won't change the status.
-  endpoint->unsubscribe (*this, presentity);
-  if (presentity) {
-
-    // FIXME : the following actions should probably be done by opal itself,
-    // remembering what ekiga asked...
-    for (std::set<std::string>::iterator iter = watched_uris.begin ();
-         iter != watched_uris.end (); ++iter) {
-      presentity->UnsubscribeFromPresence (PString (*iter));
-      Ekiga::Runtime::run_in_main (boost::bind (&Opal::Account::presence_status_in_main, this, (*iter), "unknown", ""));
-    }
-  }
 }
 
 
@@ -364,10 +382,11 @@ SIPRegister::CompatibilityModes Opal::Account::get_compat_mode () const
 
 void Opal::Account::remove ()
 {
-  enabled = false;
   dead = true;
-
-  endpoint->unsubscribe (*this, presentity);
+  if (state == Registered) {
+    disable();
+    return;
+  }
 
   trigger_saving ();
   removed ();
@@ -439,11 +458,11 @@ void Opal::Account::edit ()
   if (get_protocol_name () == "SIP")
     /* Translators:
      * SIP knows two usernames: The name for the client ("User") and the name
-     * for the authentication procedure ("Authentication User") */
-    request->text ("authentication_user", _("Authentication User:"), get_authentication_username (), _("The user name used during authentication, if different than the user name; leave empty if you do not have one"));
+     * for the authentication procedure ("Authentication user") */
+    request->text ("authentication_user", _("Authentication user:"), get_authentication_username (), _("The user name used during authentication, if different than the user name; leave empty if you do not have one"));
   request->private_text ("password", _("Password:"), get_password (), _("Password associated to the user"));
   request->text ("timeout", _("Timeout:"), str.str (), _("Time in seconds after which the account registration is automatically retried"));
-  request->boolean ("enabled", _("Enable Account"), enabled);
+  request->boolean ("enabled", _("Enable account"), enabled);
 
   questions (request);
 }
@@ -465,6 +484,8 @@ void Opal::Account::on_edit_form_submitted (bool submitted,
     new_authentication_user = new_user;
   std::string new_password = result.private_text ("password");
   bool new_enabled = result.boolean ("enabled");
+  bool should_enable = false;
+  bool should_disable = false;
   unsigned new_timeout = atoi (result.text ("timeout").c_str ());
   std::string error;
 
@@ -487,7 +508,26 @@ void Opal::Account::on_edit_form_submitted (bool submitted,
   }
   else {
 
-    disable ();
+    // Account was enabled and is now disabled
+    // Disable it
+    if (enabled != new_enabled && !new_enabled) {
+      should_disable = true;
+    }
+    // Account was disabled and is now enabled
+    // or account was already enabled
+    else if (new_enabled) {
+      // Some critical setting just changed
+      if (host != new_host || username != new_user
+          || auth_username != new_authentication_user
+          || password != new_password
+          || timeout != new_timeout
+          || enabled != new_enabled) {
+
+        should_enable = true;
+      }
+    }
+
+    enabled = new_enabled;
     name = new_name;
     host = new_host;
     username = new_user;
@@ -495,8 +535,11 @@ void Opal::Account::on_edit_form_submitted (bool submitted,
     password = new_password;
     timeout = new_timeout;
     enabled = new_enabled;
-    if (enabled)
+
+    if (should_enable)
       enable ();
+    else if (should_disable)
+      disable ();
 
     updated ();
     trigger_saving ();
@@ -547,7 +590,7 @@ Opal::Account::publish (const Ekiga::PersonalDetails& details)
 
   if (presentity) {
     presentity->SetLocalPresence (personal_state, presence_status);
-    PTRACE (4, "Ekiga sent its own presence (publish) for " << get_aor() << ": " << presence << ", note " << presence_status);
+    PTRACE (4, "Ekiga\tSent its own presence (publish) for " << get_aor() << ": " << presence << ", note " << presence_status);
   }
 }
 
@@ -577,6 +620,7 @@ Opal::Account::unfetch (const std::string uri)
   if (is_myself (uri) && presentity) {
     presentity->UnsubscribeFromPresence (PString (uri));
     watched_uris.erase (uri);
+    Ekiga::Runtime::run_in_main (boost::bind (&Opal::Account::presence_status_in_main, this, uri, "unknown", ""));
   }
 }
 
@@ -617,6 +661,7 @@ Opal::Account::handle_registration_event (RegistrationState state_,
     // "(you are) unregistered", and not as "(you have been) unregistered"
     status = _("Unregistered");
     failed_registration_already_notified = false;
+    state = state_;
 
     updated ();
     /* delay destruction of this account until the
@@ -627,6 +672,7 @@ Opal::Account::handle_registration_event (RegistrationState state_,
 
   case UnregistrationFailed:
 
+    state = state_;
     status = _("Could not unregister");
     failed_registration_already_notified = false;
     if (!info.empty ())
@@ -636,55 +682,73 @@ Opal::Account::handle_registration_event (RegistrationState state_,
 
   case RegistrationFailed:
 
-    switch (compat_mode) {
-    case SIPRegister::e_FullyCompliant:
-      // FullyCompliant did not work, try next compat mode
-      compat_mode = SIPRegister::e_CannotRegisterMultipleContacts;
-      PTRACE (4, "Register failed in FullyCompliant mode, retrying in CannotRegisterMultipleContacts mode");
-      endpoint->subscribe (*this, presentity);
-      break;
-    case SIPRegister::e_CannotRegisterMultipleContacts:
-      // CannotRegMC did not work, try next compat mode
-      compat_mode = SIPRegister::e_CannotRegisterPrivateContacts;
-      PTRACE (4, "Register failed in CannotRegisterMultipleContacts mode, retrying in CannotRegisterPrivateContacts mode");
-      endpoint->subscribe (*this, presentity);
-      break;
-    case SIPRegister::e_CannotRegisterPrivateContacts:
-      // CannotRegMC did not work, try next compat mode
-      compat_mode = SIPRegister::e_HasApplicationLayerGateway;
-      PTRACE (4, "Register failed in CannotRegisterMultipleContacts mode, retrying in HasApplicationLayerGateway mode");
-      endpoint->subscribe (*this, presentity);
-      break;
-    case SIPRegister::e_HasApplicationLayerGateway:
-      // HasAppLG did not work, stop registration with error
-      compat_mode = SIPRegister::e_FullyCompliant;
-      PTRACE (4, "Register failed in HasApplicationLayerGateway mode, aborting registration");
-      status = _("Could not register");
-      if (!info.empty ())
-        status = status + " (" + info + ")";
-      if (!failed_registration_already_notified) {
-        updated ();
+    state = state_;
+#ifdef HAVE_H323
+    if (type == Account::H323) {
         std::stringstream msg;
         msg << _("Could not register to ") << get_name ();
         boost::shared_ptr<Ekiga::Notification> notif (new Ekiga::Notification (Ekiga::Notification::Warning, msg.str (), info, _("Edit"), boost::bind (&Opal::Account::edit, (Opal::Account*) this)));
         notification_core->push_notification (notif);
-      }
-      failed_registration_already_notified = true;
-      break;
-    default:
-      break;
     }
+    else {
+#endif
+      switch (compat_mode) {
+      case SIPRegister::e_FullyCompliant:
+        // FullyCompliant did not work, try next compat mode
+        compat_mode = SIPRegister::e_CannotRegisterMultipleContacts;
+        PTRACE (4, "Register failed in FullyCompliant mode, retrying in CannotRegisterMultipleContacts mode");
+        sip_endpoint->subscribe (*this, presentity);
+        break;
+      case SIPRegister::e_CannotRegisterMultipleContacts:
+        // CannotRegMC did not work, try next compat mode
+        compat_mode = SIPRegister::e_CannotRegisterPrivateContacts;
+        PTRACE (4, "Register failed in CannotRegisterMultipleContacts mode, retrying in CannotRegisterPrivateContacts mode");
+        sip_endpoint->subscribe (*this, presentity);
+        break;
+      case SIPRegister::e_CannotRegisterPrivateContacts:
+        // CannotRegMC did not work, try next compat mode
+        compat_mode = SIPRegister::e_HasApplicationLayerGateway;
+        PTRACE (4, "Register failed in CannotRegisterMultipleContacts mode, retrying in HasApplicationLayerGateway mode");
+        sip_endpoint->subscribe (*this, presentity);
+        break;
+      case SIPRegister::e_HasApplicationLayerGateway:
+        // HasAppLG did not work, stop registration with error
+        compat_mode = SIPRegister::e_FullyCompliant;
+        PTRACE (4, "Register failed in HasApplicationLayerGateway mode, aborting registration");
+        status = _("Could not register");
+        if (!info.empty ())
+          status = status + " (" + info + ")";
+        if (!failed_registration_already_notified) {
+          std::stringstream msg;
+          msg << _("Could not register to ") << get_name ();
+          boost::shared_ptr<Ekiga::Notification> notif (new Ekiga::Notification (Ekiga::Notification::Warning, msg.str (), info, _("Edit"), boost::bind (&Opal::Account::edit, (Opal::Account*) this)));
+          notification_core->push_notification (notif);
+        }
+        updated ();
+        failed_registration_already_notified = true;
+        break;
+      default:
+
+        state = state_;
+        updated();
+        break;
+      }
+#ifdef HAVE_H323
+    }
+#endif
     break;
 
   case Processing:
 
+    state = state_;
     status = _("Processing...");
     updated ();
   default:
+
+    state = state_;
+    updated();
     break;
   }
-
-  state = state_;
 }
 
 void
@@ -743,7 +807,7 @@ Opal::Account::OnPresenceChange (OpalPresentity& /*presentity*/,
   std::string uri = sip_uri.AsString ();
   PCaselessString note = info.m_note;
 
-  PTRACE (4, "Ekiga received a presence change (notify) for " << info.m_entity << ": state " << info.m_state << ", note " << info.m_note);
+  PTRACE (4, "Ekiga\tReceived a presence change (notify) for " << info.m_entity << ": state " << info.m_state << ", note " << info.m_note);
 
   if (info.m_state == OpalPresenceInfo::Unchanged)
     return;
@@ -780,12 +844,14 @@ Opal::Account::OnPresenceChange (OpalPresentity& /*presentity*/,
       }
     }
     break;
+  case OpalPresenceInfo::NoPresence:
+    new_presence = "offline";
+    break;
   case OpalPresenceInfo::InternalError:
   case OpalPresenceInfo::Forbidden:
-  case OpalPresenceInfo::NoPresence:
   case OpalPresenceInfo::Unavailable:
   case OpalPresenceInfo::UnknownExtended:
-    new_presence = "offline";
+    new_presence = "unknown";
     break;
   case OpalPresenceInfo::Away:
     new_presence = "away";
@@ -794,7 +860,7 @@ Opal::Account::OnPresenceChange (OpalPresentity& /*presentity*/,
     new_presence = "busy";
     break;
   case OpalPresenceInfo::Appointment:
-    new_presence = "busy";
+    new_presence = "away";
     // Translators: see RFC 4480 for more information about activities
     if (new_status.empty ())
       new_status = _("Appointment");
@@ -846,7 +912,7 @@ Opal::Account::OnPresenceChange (OpalPresentity& /*presentity*/,
       new_status = _("On the phone");
     break;
   case OpalPresenceInfo::Playing:
-    new_presence = "busy";
+    new_presence = "away";
     if (new_status.empty ())
       new_status = _("Playing");
     break;
