@@ -145,12 +145,7 @@ namespace Opal {
 		     SIPRegister::CompatibilityModes compat_mode,
 		     unsigned timeout);
 
-      void OnRegistered (const PString & aor,
-                         bool wasRegistering);
-
-      void OnRegistrationFailed (const PString & aor,
-                                 SIP_PDU::StatusCodes reason,
-                                 bool wasRegistering);
+      void OnRegistrationStatus (const RegistrationStatus & status);
 
       void OnMWIReceived (const PString & party,
                           OpalManager::MessageWaitingType type,
@@ -162,8 +157,6 @@ namespace Opal {
 
       void OnDialogInfoReceived (const SIPDialogNotification & info);
 
-      PBoolean OnReceivedINVITE (OpalTransport & transport, SIP_PDU * pdu);
-
       bool OnReceivedMESSAGE (OpalTransport & transport,
                               SIP_PDU & pdu);
 
@@ -216,7 +209,6 @@ namespace Opal {
       std::string outbound_proxy;
 
       unsigned listen_port;
-      bool auto_answer_call;
 
       boost::weak_ptr<Opal::Bank> bank;
       boost::shared_ptr<SIP::Dialect> dialect;
