@@ -647,7 +647,7 @@ FormDialog::FormDialog (Ekiga::FormRequestPtr _request,
 
   vbox = gtk_vbox_new (FALSE, 0);
   gtk_container_set_border_width (GTK_CONTAINER (vbox), 6);
-  gtk_box_pack_start (GTK_BOX (GTK_DIALOG (window)->vbox), vbox, FALSE, FALSE, 0);
+  gtk_box_pack_start (GTK_BOX (gtk_dialog_get_content_area (GTK_DIALOG (window))), vbox, FALSE, FALSE, 0);
   gtk_widget_show (vbox);
 
   preamble = gtk_vbox_new (FALSE, 0);
@@ -1303,7 +1303,7 @@ FormDialog::editable_set (const std::string name,
 
   hbox = gtk_hbox_new (FALSE, 2);
   entry = gtk_entry_new ();
-  button = gtk_button_new_from_stock (GTK_STOCK_ADD);
+  button = gtk_button_new_with_label (_("Add Group"));
   gtk_box_pack_start (GTK_BOX (hbox), entry, TRUE, TRUE, 2);
   gtk_box_pack_start (GTK_BOX (hbox), button, FALSE, FALSE, 2);
 
