@@ -126,16 +126,15 @@ static void gm_prefs_window_sound_events_list_build (GtkWidget *prefs_window);
  * BEHAVIOR     : Adds an update button connected to the given callback to
  * 		  the given GtkBox.
  * PRE          : A valid pointer to the container widget where to attach
- *        the button, followed by a stock ID, a label, the callback, a
- *        tooltip and the alignment.
+ *                the button, followed by a label, the callback, a
+ *                tooltip and the alignment.
  */
 static void gm_pw_add_update_button (GtkWidget *box,
-					   const char *stock_id,
-					   const char *label,
-					   GCallback func,
-					   const gchar *tooltip,
-					   gfloat valign,
-					   gpointer data);
+                                     const char *label,
+                                     GCallback func,
+                                     const gchar *tooltip,
+                                     gfloat valign,
+                                     gpointer data);
 
 
 /* DESCRIPTION  : /
@@ -421,7 +420,6 @@ gm_prefs_window_sound_events_list_build (GtkWidget *prefs_window)
 
 static void
 gm_pw_add_update_button (GtkWidget *box,
-                         const char *stock_id,
                          const char *label,
                          GCallback func,
                          const gchar *tooltip,
@@ -429,13 +427,10 @@ gm_pw_add_update_button (GtkWidget *box,
                          gpointer data)
 {
   GtkWidget* alignment = NULL;
-  GtkWidget* image = NULL;
   GtkWidget* button = NULL;
 
   /* Update Button */
   button = gtk_button_new_with_mnemonic (label);
-  image = gtk_image_new_from_stock (stock_id, GTK_ICON_SIZE_BUTTON);
-  gtk_button_set_image (GTK_BUTTON (button), image);
   gtk_widget_set_tooltip_text (button, tooltip);
 
   alignment = gtk_alignment_new (1, valign, 0, 0);
@@ -718,7 +713,7 @@ gm_pw_init_sip_page (GtkWidget *prefs_window,
   subsection = gnome_prefs_subsection_new (prefs_window, container,
                                            _("Misc Settings"), 2, 2);
 
-  gnome_prefs_entry_new (subsection, _("_Outbound Proxy:"), SIP_KEY "outbound_proxy_host", _("The SIP Outbound Proxy to use for outgoing calls"), 0, false);
+  gnome_prefs_entry_new (subsection, _("_Outbound proxy:"), SIP_KEY "outbound_proxy_host", _("The SIP Outbound Proxy to use for outgoing calls"), 0, false);
 
   entry =
     gnome_prefs_entry_new (subsection, _("Forward _URI:"), SIP_KEY "forward_host", _("The host where calls should be forwarded if call forwarding is enabled"), 1, false);
@@ -754,7 +749,7 @@ gm_pw_init_audio_devices_page (GtkWidget *prefs_window,
   gm_prefs_window_get_audiooutput_devices_list (pw->core, device_list);
   array = gm_prefs_window_convert_string_list(device_list);
   pw->sound_events_output =
-    gnome_prefs_string_option_menu_new (subsection, _("Ringing Device"), (const gchar **)array, SOUND_EVENTS_KEY "output_device", _("Select the ringing audio device to use"), 0, DEFAULT_AUDIO_DEVICE_NAME);
+    gnome_prefs_string_option_menu_new (subsection, _("Ringing device:"), (const gchar **)array, SOUND_EVENTS_KEY "output_device", _("Select the ringing audio device to use"), 0, DEFAULT_AUDIO_DEVICE_NAME);
   pw->audio_player =
     gnome_prefs_string_option_menu_new (subsection, _("Output device:"), (const gchar **)array, AUDIO_DEVICES_KEY "output_device", _("Select the audio output device to use"), 1, DEFAULT_AUDIO_DEVICE_NAME);
   g_free (array);
@@ -767,7 +762,7 @@ gm_pw_init_audio_devices_page (GtkWidget *prefs_window,
   g_free (array);
 
   /* That button will refresh the device list */
-  gm_pw_add_update_button (container, GTK_STOCK_REFRESH, _("_Detect devices"), G_CALLBACK (refresh_devices_list_cb), _("Click here to refresh the device list"), 1, prefs_window);
+  gm_pw_add_update_button (container, _("_Detect devices"), G_CALLBACK (refresh_devices_list_cb), _("Click here to refresh the device list"), 1, prefs_window);
 }
 
 
@@ -910,7 +905,7 @@ gm_pw_init_video_devices_page (GtkWidget *prefs_window,
   gnome_prefs_int_option_menu_new (subsection, _("Format:"), video_format, VIDEO_DEVICES_KEY "format", _("Select the format for video cameras (does not apply to most USB cameras)"), 2);
 
   /* That button will refresh the device list */
-  gm_pw_add_update_button (container, GTK_STOCK_REFRESH, _("_Detect devices"), G_CALLBACK (refresh_devices_list_cb), _("Click here to refresh the device list"), 1, prefs_window);
+  gm_pw_add_update_button (container, _("_Detect devices"), G_CALLBACK (refresh_devices_list_cb), _("Click here to refresh the device list"), 1, prefs_window);
 
   for (i=0; i< NB_VIDEO_SIZES; i++)
     g_free (video_size[i]);
@@ -974,7 +969,7 @@ gm_pw_init_video_codecs_page (GtkWidget *prefs_window,
 				_("Settings"), 3, 1);
 
   /* Translators: the full sentence is Keep a minimum video quality of X % */
-  gnome_prefs_scale_new (subsection, _("Picture Quality"), _("Frame Rate"), VIDEO_CODECS_KEY "temporal_spatial_tradeoff", _("Choose if you want to guarantee a minimum image quality (possibly leading to dropped frames in order not to surpass the bitrate limit) or if you prefer to keep the frame rate"), 0.0, 32.0, 1.0, 2);
+  gnome_prefs_scale_new (subsection, _("Picture quality"), _("Frame rate"), VIDEO_CODECS_KEY "temporal_spatial_tradeoff", _("Choose if you want to guarantee a minimum image quality (possibly leading to dropped frames in order not to surpass the bitrate limit) or if you prefer to keep the frame rate"), 0.0, 32.0, 1.0, 2);
 
   gnome_prefs_spin_new (subsection, _("Maximum video _bitrate (in kbits/s):"), VIDEO_CODECS_KEY "maximum_video_tx_bitrate", _("The maximum video bitrate in kbits/s. The video quality and the effective frame rate will be dynamically adjusted to keep the bitrate at the given value."), 16.0, 10240.0, 1.0, 1, NULL, true);
 }
