@@ -38,6 +38,7 @@
 #include <algorithm>
 #include <iostream>
 #include <vector>
+#include <ctime>
 #include <glib/gi18n.h>
 #include <gdk/gdkkeysyms.h>
 
@@ -66,6 +67,15 @@ struct _RosterViewGtkPrivate
   gboolean show_offline_contacts;
 };
 
+typedef struct _StatusIconInfo {
+
+  GtkTreeModel *model;
+  GtkTreeIter *iter;
+  std::string new_presence;
+  int cpt;
+
+} StatusIconInfo;
+
 /* the different type of things which will appear in the view */
 enum {
 
@@ -104,9 +114,10 @@ enum {
   COLUMN_PRESENTITY,
   COLUMN_NAME,
   COLUMN_STATUS,
-  COLUMN_PRESENCE,
+  COLUMN_PRESENCE_ICON,
   COLUMN_ACTIVE,
-  COLUMN_GROUP_SIZE,
+  COLUMN_GROUP_NAME,
+  COLUMN_PRESENCE,
   COLUMN_OFFLINE,
   COLUMN_NUMBER
 };
@@ -116,6 +127,14 @@ enum {
  */
 //static void dump_model_content (GtkTreeModel* model);
 
+/*
+ * Time out callbacks
+ */
+static int roster_view_gtk_icon_blink_cb (gpointer data);
+
+static void status_icon_info_delete (gpointer info);
+
+
 /*
  * Helpers
  */
@@ -439,8 +458,47 @@ static void roster_view_gtk_set_core (RosterViewGtk* self,
 //     g_print ("(empty model)\n");
 // }
 
-/* Implementation of the helpers */
 
+/* Implementation of the timer callbacks */
+static int
+roster_view_gtk_icon_blink_cb (gpointer data)
+{
+  g_return_val_if_fail (data != NULL, FALSE);
+
+  StatusIconInfo *info = (StatusIconInfo*) data;
+  time_t now = time (0);
+  tm *ltm = localtime (&now);
+
+  std::string icon = "avatar-default";
+  if (info->cpt == 0) {
+    gtk_tree_store_set (GTK_TREE_STORE (info->model), info->iter,
+                        COLUMN_PRESENCE_ICON, "exit",
+                        -1);
+  }
+  else if (ltm->tm_sec % 5 == 0 && info->cpt > 3) {
+    if (info->new_presence != "unknown")
+      icon = "user-" + info->new_presence;
+    gtk_tree_store_set (GTK_TREE_STORE (info->model), info->iter,
+                        COLUMN_PRESENCE_ICON, icon.c_str (),
+                        -1);
+    return FALSE;
+  }
+
+  info->cpt++;
+  return TRUE;
+}
+
+static void status_icon_info_delete (gpointer data)
+{
+  g_return_if_fail (data != NULL);
+  StatusIconInfo *info = (StatusIconInfo*) data;
+
+  gtk_tree_iter_free (info->iter);
+
+  delete info;
+}
+
+/* Implementation of the helpers */
 static void
 on_clicked_show_heap_menu (Ekiga::Heap* heap,
 			   GdkEventButton* event)
@@ -555,7 +613,8 @@ update_offline_count (RosterViewGtk* self,
   gint offline_count = 0;
   gint column_type;
   Ekiga::Presentity* presentity = NULL;
-  gchar *size = NULL;
+  gchar *name = NULL;
+  gchar *name_with_count = NULL;
 
   model = GTK_TREE_MODEL (self->priv->store);
 
@@ -575,11 +634,12 @@ update_offline_count (RosterViewGtk* self,
   }
 
   total = gtk_tree_model_iter_n_children (model, iter);
-  size = g_strdup_printf ("(%d/%d)", total - offline_count, total);
+  gtk_tree_model_get (model, iter, COLUMN_GROUP_NAME, &name, -1);
+  name_with_count = g_strdup_printf ("%s - (%d/%d)", name, total - offline_count, total);
   gtk_tree_store_set (GTK_TREE_STORE (model), iter,
-                      COLUMN_GROUP_SIZE, size,
-                      -1);
-  g_free (size);
+                      COLUMN_NAME, name_with_count, -1);
+  g_free (name);
+  g_free (name_with_count);
 }
 
 static void
@@ -670,10 +730,12 @@ on_view_event_after (GtkWidget *tree_view,
 
     gint column_type;
     gchar *name = NULL;
+    gchar *group_name = NULL;
     Ekiga::Heap *heap = NULL;
     Ekiga::Presentity *presentity = NULL;
     gtk_tree_model_get (model, &iter,
                         COLUMN_NAME, &name,
+                        COLUMN_GROUP_NAME, &group_name,
                         COLUMN_TYPE, &column_type,
                         COLUMN_HEAP, &heap,
                         COLUMN_PRESENTITY, &presentity,
@@ -690,10 +752,10 @@ on_view_event_after (GtkWidget *tree_view,
       break;
     case TYPE_GROUP:
 
-      if (event->type == GDK_BUTTON_PRESS && event->button == 1 && name)
-        on_clicked_fold (self, path, name);
+      if (event->type == GDK_BUTTON_PRESS && event->button == 1 && group_name)
+        on_clicked_fold (self, path, group_name);
       if (event->type == GDK_BUTTON_PRESS && event->button == 3)
-        on_clicked_show_heap_group_menu (heap, name, event);
+        on_clicked_show_heap_group_menu (heap, group_name, event);
       break;
     case TYPE_PRESENTITY:
 
@@ -823,7 +885,7 @@ expand_cell_data_func (GtkTreeViewColumn *column,
   gboolean row_expanded = FALSE;
 
   path = gtk_tree_model_get_path (model, iter);
-  row_expanded = gtk_tree_view_row_expanded (GTK_TREE_VIEW (column->tree_view), path);
+  row_expanded = gtk_tree_view_row_expanded (GTK_TREE_VIEW (gtk_tree_view_column_get_tree_view (column)), path);
   gtk_tree_path_free (path);
 
   gtk_tree_model_get (model, iter, COLUMN_TYPE, &column_type, -1);
@@ -942,6 +1004,7 @@ on_presentity_added (RosterViewGtk* self,
   GtkTreeIter filtered_iter;
   bool active = false;
   bool away = false;
+  gchar *old_presence = NULL;
   gboolean should_emit = FALSE;
 
   roster_view_gtk_find_iter_for_heap (self, heap, &heap_iter);
@@ -964,19 +1027,45 @@ on_presentity_added (RosterViewGtk* self,
       if (gtk_tree_selection_iter_is_selected (selection, &filtered_iter))
 	should_emit = TRUE;
 
-    std::string icon = "avatar-default";
-    if (presentity->get_presence () != "unknown")
-      icon = "user-" + presentity->get_presence ();
+    // Find out what our presence was
+    gtk_tree_model_get (GTK_TREE_MODEL (self->priv->store), &iter,
+                        COLUMN_PRESENCE, &old_presence,
+                        -1);
+    if (old_presence && presentity->get_presence () != old_presence
+        && presentity->get_presence () != "unknown" && presentity->get_presence () != "offline"
+        && (!strcmp (old_presence, "unknown") || !strcmp (old_presence, "offline"))) {
+
+      StatusIconInfo *info = new StatusIconInfo ();
+      info->model = GTK_TREE_MODEL (self->priv->store);
+      info->iter = gtk_tree_iter_copy (&iter);
+      info->new_presence = presentity->get_presence ();
+      info->cpt = 0;
+
+      g_timeout_add_seconds_full (G_PRIORITY_DEFAULT, 1, roster_view_gtk_icon_blink_cb,
+                                  (gpointer) info, (GDestroyNotify) status_icon_info_delete);
+    }
+    else {
+
+      if (!old_presence || old_presence != presentity->get_presence ()) {
+        std::string icon = "avatar-default";
+        if (presentity->get_presence () != "unknown")
+          icon = "user-" + presentity->get_presence ();
+        gtk_tree_store_set (self->priv->store, &iter,
+                            COLUMN_PRESENCE_ICON, icon.c_str (),
+                            -1);
+      }
+    }
     gtk_tree_store_set (self->priv->store, &iter,
-			COLUMN_TYPE, TYPE_PRESENTITY,
-			COLUMN_OFFLINE, active,
-			COLUMN_HEAP, heap.get (),
-			COLUMN_PRESENTITY, presentity.get (),
-			COLUMN_NAME, presentity->get_name ().c_str (),
-			COLUMN_STATUS, presentity->get_status ().c_str (),
-			COLUMN_PRESENCE, icon.c_str (),
-			COLUMN_ACTIVE, (!active || away) ? "gray" : "black",
-			-1);
+                        COLUMN_TYPE, TYPE_PRESENTITY,
+                        COLUMN_OFFLINE, active,
+                        COLUMN_HEAP, heap.get (),
+                        COLUMN_PRESENTITY, presentity.get (),
+                        COLUMN_NAME, presentity->get_name ().c_str (),
+                        COLUMN_STATUS, presentity->get_status ().c_str (),
+                        COLUMN_PRESENCE, presentity->get_presence ().c_str (),
+                        COLUMN_ACTIVE, (!active || away) ? "gray" : "black",
+                        -1);
+    g_free (old_presence);
   }
 
   GtkTreeModel* model = gtk_tree_view_get_model (self->priv->tree_view);
@@ -1018,7 +1107,7 @@ on_presentity_updated (RosterViewGtk* self,
     do {
 
       gtk_tree_model_get (model, &group_iter,
-                          COLUMN_NAME, &group_name,
+                          COLUMN_GROUP_NAME, &group_name,
                           -1);
       if (group_name != NULL) {
 
@@ -1124,7 +1213,7 @@ roster_view_gtk_find_iter_for_group (RosterViewGtk *view,
 
     do {
 
-      gtk_tree_model_get (model, iter, COLUMN_NAME, &group_name, -1);
+      gtk_tree_model_get (model, iter, COLUMN_GROUP_NAME, &group_name, -1);
       if (group_name != NULL && name == group_name)
         found = TRUE;
       if (group_name != NULL)
@@ -1139,6 +1228,7 @@ roster_view_gtk_find_iter_for_group (RosterViewGtk *view,
                         COLUMN_TYPE, TYPE_GROUP,
                         COLUMN_HEAP, heap.get (),
                         COLUMN_NAME, name.c_str (),
+                        COLUMN_GROUP_NAME, name.c_str (),
                         -1);
   }
 }
@@ -1196,7 +1286,7 @@ roster_view_gtk_update_groups (RosterViewGtk *view,
 
         update_offline_count (view, &iter);
         gtk_tree_model_get (model, &iter,
-                            COLUMN_NAME, &name, -1);
+                            COLUMN_GROUP_NAME, &name, -1);
         if (name) {
 
           if (view->priv->folded_groups)
@@ -1345,7 +1435,8 @@ roster_view_gtk_init (G_GNUC_UNUSED RosterViewGtk* self)
                                           G_TYPE_STRING,      // status
                                           G_TYPE_STRING,      // presence
                                           G_TYPE_STRING,      // color if active
-					  G_TYPE_STRING,      // group size
+                                          G_TYPE_STRING,      // group name (invisible)
+                                          G_TYPE_STRING,      // presence
 					  G_TYPE_BOOLEAN);    // offline
 
   gtk_tree_sortable_set_sort_column_id (GTK_TREE_SORTABLE (self->priv->store),
@@ -1414,11 +1505,12 @@ roster_view_gtk_init (G_GNUC_UNUSED RosterViewGtk* self)
   gtk_tree_view_column_pack_start (col, renderer, FALSE);
   gtk_tree_view_column_add_attribute (col, renderer,
 				      "icon-name",
-				      COLUMN_PRESENCE);
+				      COLUMN_PRESENCE_ICON);
   gtk_tree_view_column_set_cell_data_func (col, renderer,
                                            show_cell_data_func, GINT_TO_POINTER (TYPE_PRESENTITY), NULL);
 
   renderer = gm_cell_renderer_bitext_new ();
+  g_object_set (renderer, "ellipsize", PANGO_ELLIPSIZE_END, "width-chars", 30, NULL);
   gtk_tree_view_column_pack_start (col, renderer, FALSE);
   gtk_tree_view_column_add_attribute (col, renderer, "primary-text", COLUMN_NAME);
   gtk_tree_view_column_add_attribute (col, renderer, "secondary-text", COLUMN_STATUS);
@@ -1426,15 +1518,6 @@ roster_view_gtk_init (G_GNUC_UNUSED RosterViewGtk* self)
   gtk_tree_view_column_set_cell_data_func (col, renderer,
                                            show_cell_data_func, GINT_TO_POINTER (TYPE_PRESENTITY), NULL);
 
-  renderer = gtk_cell_renderer_text_new ();
-  gtk_tree_view_column_set_spacing (col, 0);
-  gtk_tree_view_column_pack_start (col, renderer, TRUE);
-  gtk_tree_view_column_add_attribute (col, renderer, "text", COLUMN_GROUP_SIZE);
-  gtk_tree_view_column_set_alignment (col, 0.0);
-  gtk_tree_view_column_set_cell_data_func (col, renderer,
-					   show_cell_data_func,
-					   GINT_TO_POINTER (TYPE_GROUP), NULL);
-
   /* Callback when the selection has been changed */
   selection = gtk_tree_view_get_selection (self->priv->tree_view);
   gtk_tree_selection_set_mode (selection, GTK_SELECTION_SINGLE);
@@ -1500,7 +1583,7 @@ roster_view_gtk_populate_menu_for_selected (RosterViewGtk* self,
     Ekiga::Heap* heap = NULL;
     Ekiga::Presentity *presentity = NULL;
     gtk_tree_model_get (model, &iter,
-			COLUMN_NAME, &name,
+			COLUMN_GROUP_NAME, &name,
 			COLUMN_TYPE, &column_type,
 			COLUMN_HEAP, &heap,
 			COLUMN_PRESENTITY, &presentity,
