@@ -71,9 +71,6 @@
 
 #include <algorithm>
 
-// this is a bad way to do things,but still
-#undef CORE_ACTIONS_MENU
-
 enum CallingState {Standby, Calling, Connected, Called};
 
 enum DeviceType {AudioInput, AudioOutput, Ringer, VideoInput};
@@ -670,7 +667,6 @@ static void on_cleared_call_cb (boost::shared_ptr<Ekiga::CallManager>  /*manager
                                 gpointer self)
 {
   EkigaMainWindow *mw = EKIGA_MAIN_WINDOW (self);
-  GtkWidget *call_window = NULL;
 
   if (mw->priv->current_call && mw->priv->current_call->get_id () != call->get_id ()) {
     return; // Trying to clear another call than the current active one
@@ -690,11 +686,7 @@ static void on_cleared_call_cb (boost::shared_ptr<Ekiga::CallManager>  /*manager
   audiooutput_core->stop_play_event("ring_tone_sound");
 
   /* Hide call window */
-  if (!gm_conf_get_bool (VIDEO_DEVICES_KEY "enable_preview")) {
-    boost::shared_ptr<GtkFrontend> gtk_frontend = mw->priv->core->get<GtkFrontend> ("gtk-frontend");
-    call_window = GTK_WIDGET (gtk_frontend->get_call_window ());
-    g_timeout_add_seconds (2, on_delayed_hide_call_window_cb, call_window);
-  }
+  g_timeout_add_seconds (2, on_delayed_hide_call_window_cb, mw);
 
   /* Sensitive a few things back */
   gtk_widget_set_sensitive (GTK_WIDGET (mw->priv->uri_toolbar), true);
@@ -759,13 +751,22 @@ static bool on_handle_errors (std::string error,
 
 
 /* GTK callbacks */
+// FIXME: I should probably be moved to CallWindow code
 static gboolean
 on_delayed_hide_call_window_cb (gpointer data)
 {
+  GtkWidget* call_window = NULL;
+
   g_return_val_if_fail (data != NULL, FALSE);
   g_return_val_if_fail (GTK_IS_WIDGET (data), FALSE);
 
-  gtk_widget_hide (GTK_WIDGET (data));
+  EkigaMainWindow *mw = EKIGA_MAIN_WINDOW (data);
+
+  boost::shared_ptr<GtkFrontend> gtk_frontend = mw->priv->core->get<GtkFrontend> ("gtk-frontend");
+  call_window = GTK_WIDGET (gtk_frontend->get_call_window ());
+
+  if (!mw->priv->current_call && !gm_conf_get_bool (VIDEO_DEVICES_KEY "enable_preview"))
+    gtk_widget_hide (GTK_WIDGET (call_window));
 
   return FALSE;
 }
@@ -940,6 +941,7 @@ video_preview_changed_nt (G_GNUC_UNUSED gpointer id,
     EkigaMainWindow* mw = EKIGA_MAIN_WINDOW (data);
     boost::shared_ptr<GtkFrontend> gtk_frontend = mw->priv->core->get<GtkFrontend> ("gtk-frontend");
     GtkWidget *call_window = GTK_WIDGET (gtk_frontend->get_call_window ());
+    GtkWidget *menu_item = NULL;
 
     if (gm_conf_entry_get_type (entry) == GM_CONF_BOOL) {
       if (mw->priv->calling_state == Standby) {
@@ -951,6 +953,8 @@ video_preview_changed_nt (G_GNUC_UNUSED gpointer id,
         }
         g_signal_handlers_block_by_func (mw->priv->preview_button,
                                          (gpointer) video_preview_action_toggled_cb, mw);
+        menu_item = gtk_menu_get_widget (mw->priv->main_menu, "preview");
+        gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (menu_item), gm_conf_entry_get_bool (entry));
         gtk_toggle_tool_button_set_active (GTK_TOGGLE_TOOL_BUTTON (mw->priv->preview_button),
                                            gm_conf_entry_get_bool (entry));
         g_signal_handlers_unblock_by_func (mw->priv->preview_button,
@@ -1186,7 +1190,7 @@ ekiga_main_window_init_actions_toolbar (EkigaMainWindow *mw)
   gtk_toolbar_set_show_arrow (GTK_TOOLBAR (mw->priv->actions_toolbar), FALSE);
 
   /* The video preview button */
-  image = gtk_image_new_from_icon_name ("camera-video", GTK_ICON_SIZE_MENU);
+  image = gtk_image_new_from_icon_name ("camera-web", GTK_ICON_SIZE_MENU);
   mw->priv->preview_button = GTK_WIDGET (gtk_toggle_tool_button_new ());
   gtk_tool_button_set_icon_widget (GTK_TOOL_BUTTON (mw->priv->preview_button), image);
   gtk_tool_item_set_expand (GTK_TOOL_ITEM (mw->priv->preview_button), false);
@@ -1253,6 +1257,7 @@ ekiga_main_window_init_menu (EkigaMainWindow *mw)
 
   PanelSection cps = DIALPAD;
   bool show_offline_contacts = false;
+  bool enable_preview = false;
 
   g_return_if_fail (mw != NULL);
 
@@ -1268,6 +1273,7 @@ ekiga_main_window_init_menu (EkigaMainWindow *mw)
   /* Default values */
   cps = (PanelSection) gm_conf_get_int (USER_INTERFACE_KEY "main_window/panel_section");
   show_offline_contacts = gm_conf_get_bool (CONTACTS_KEY "show_offline_contacts");
+  enable_preview = gm_conf_get_bool (VIDEO_DEVICES_KEY "enable_preview");
 
   static MenuEntry gnomemeeting_menu [] =
     {
@@ -1278,7 +1284,7 @@ ekiga_main_window_init_menu (EkigaMainWindow *mw)
 		      GTK_STOCK_EXECUTE, 0,
 		      NULL, NULL, FALSE),
 
-      GTK_MENU_THEME_ENTRY("connect", _("Ca_ll a number"), _("Place a new call"),
+      GTK_MENU_THEME_ENTRY("connect", _("Ca_ll a Number"), _("Place a new call"),
                            "phone-pick-up", 'o',
                            G_CALLBACK (show_dialpad_cb), mw, TRUE),
 
@@ -1296,16 +1302,6 @@ ekiga_main_window_init_menu (EkigaMainWindow *mw)
 
       GTK_MENU_SEPARATOR,
 
-#ifdef CORE_ACTIONS_MENU
-      // FIXME: that isn't a very good way to do things
-      GTK_MENU_ENTRY ("core-actions", _("Other"),
-		      _("Other possible actions"),
-		      GTK_STOCK_EXECUTE, 0,
-		      NULL, NULL, FALSE),
-
-      GTK_MENU_SEPARATOR,
-#endif
-
       GTK_MENU_ENTRY("close", NULL, _("Close the Ekiga window"),
 		     GTK_STOCK_CLOSE, 'W',
 		     G_CALLBACK (window_closed_from_menu_cb),
@@ -1341,6 +1337,14 @@ ekiga_main_window_init_menu (EkigaMainWindow *mw)
 
       GTK_MENU_NEW(_("_View")),
 
+      GTK_MENU_TOGGLE_ENTRY("preview", _("_Video Preview"),
+                            _("Display images from your camera device"),
+                            NULL, 0,
+                            G_CALLBACK (toggle_menu_changed_cb),
+                            (gpointer) VIDEO_DEVICES_KEY "enable_preview", enable_preview, TRUE),
+
+      GTK_MENU_SEPARATOR,
+
       GTK_MENU_RADIO_ENTRY("contacts", _("Con_tacts"), _("View the contacts list"),
 			   NULL, 0,
 			   G_CALLBACK (radio_menu_changed_cb),
@@ -1359,7 +1363,7 @@ ekiga_main_window_init_menu (EkigaMainWindow *mw)
 
       GTK_MENU_SEPARATOR,
 
-      GTK_MENU_TOGGLE_ENTRY ("showofflinecontacts", _("Show offline _contacts"), _("Show offline contacts"),
+      GTK_MENU_TOGGLE_ENTRY ("showofflinecontacts", _("Show Offline _Contacts"), _("Show offline contacts"),
                              NULL, 0,
                              G_CALLBACK (toggle_menu_changed_cb),
                              (gpointer) CONTACTS_KEY "show_offline_contacts",
